PCB Environment: math::Moments Struct Reference

PCB Environment 2

Loading...
Searching...
No Matches
Public Member Functions | Data Fields
math::Moments Struct Reference

## Public Member Functions
Moments & | operator+= (float v)
Moments & | operator+= (const Moments &A)

## Data Fields
float | m1 {0.0f}
float | m2 {0.0f}
uint | N {0}

The documentation for this struct was generated from the following file:

- /home/chr/devel/PhD/Environment/pub/PCBEnv/pcbenv/cxx/Math/Moments.hpp